#ifndef NT2_INCLUDE_CONSTANTS_NBEXPONENTBITS_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_NBEXPONENTBITS_HPP_INCLUDED

#include <nt2/constant/include/constants/nbexponentbits.hpp>

#endif
